<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="id">
<context>
    <name>CountdownTooltip</name>
    <message>
        <source>Click the tray icon 
or press the shortcut again to stop recording</source>
        <translation>Klik ikon laci 
atau tekan pemintas lagi untuk berhenti merekam</translation>
    </message>
    <message>
        <source>Do not rotate your screen during recording</source>
        <translation>Jangan putar layar Anda ketika merekam</translation>
    </message>
</context>
<context>
    <name>IconWidget</name>
    <message>
        <source>Screenshot</source>
        <translation>Cuplikan layar</translation>
    </message>
    <message>
        <source>Recording</source>
        <translation>Merekam</translation>
    </message>
</context>
<context>
    <name>MainToolWidget</name>
    <message>
        <source>Record</source>
        <translation>Rekam</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>Cuplikan layar</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Screen Capture</source>
        <translation>Cuplikan layar</translation>
    </message>
    <message>
        <source>Save failed. Please save it in your home directory.</source>
        <translation>Penyimpanan gagal. Silakan simpan di direktori  home Anda</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Lihat</translation>
    </message>
    <message>
        <source>Screenshot finished</source>
        <translation>Cuplik layar selesai</translation>
    </message>
    <message>
        <source>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</source>
        <translation>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</translation>
    </message>
    <message>
        <source>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</source>
        <translation>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</translation>
    </message>
    <message>
        <source>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</source>
        <translation>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</translation>
    </message>
    <message>
        <source>select-area</source>
        <translation>pilih area</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Simpan</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>Simpan ke %1</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Abaikan</translation>
    </message>
    <message>
        <source>Clipboard</source>
        <translation>Papan Klip</translation>
    </message>
    <message>
        <source>Saving the screen recording file, please wait...</source>
        <translation>Menyimpan berkas rekaman layar, tunggu...</translation>
    </message>
    <message>
        <source>As the window effect is disabled during the process, the recording has to be stopped</source>
        <translation>Karena efek jendela dinonaktifkan selama proses tersebut, perekaman harus dihentikan</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>Cuplikan layar</translation>
    </message>
    <message>
        <source>Screenshot failed.</source>
        <translation>Screenshot gagal.</translation>
    </message>
    <message>
        <source>Scrollshot</source>
        <translation>Scrollshot</translation>
    </message>
    <message>
        <source>Pin Screenshots</source>
        <translation>Pin Screenshot</translation>
    </message>
    <message>
        <source>deepin-screen-recorder</source>
        <translation>deepin-screen-recorder</translation>
    </message>
    <message>
        <source>Open Folder</source>
        <translation>Buka Folder</translation>
    </message>
    <message>
        <source>Screenshot finished and copy to clipboard</source>
        <translation>Screenshot selesai dan salin ke papan klip</translation>
    </message>
</context>
<context>
    <name>MenuController</name>
    <message>
        <source>Undo</source>
        <translation>Batal</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Simpan</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Keluar</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Pin Screenshots</source>
        <translation>Pin Screenshot</translation>
    </message>
</context>
<context>
    <name>QuickPanelWidget</name>
    <message>
        <source>Screenshot</source>
        <translation>Screenshot</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>Rekam</translation>
    </message>
</context>
<context>
    <name>RecordIconWidget</name>
    <message>
        <source>Screenshot</source>
        <translation>Screenshot</translation>
    </message>
    <message>
        <source>Recording</source>
        <translation>Merekam</translation>
    </message>
</context>
<context>
    <name>RecordProcess</name>
    <message>
        <source>View</source>
        <translation>Lihat</translation>
    </message>
    <message>
        <source>Recording finished</source>
        <translation>Perekaman selesai</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>Simpan ke %1</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>Rekam</translation>
    </message>
    <message>
        <source>Open Folder</source>
        <translation>Buka Folder</translation>
    </message>
</context>
<context>
    <name>Screenshot</name>
    <message>
        <source>Screen Capture will start in %1 seconds</source>
        <translation>Cuplikan Layar akan dimulai pada %1 detik</translation>
    </message>
</context>
<context>
    <name>ScrollShotTip</name>
    <message>
        <source>Get help.</source>
        <translation>Dapatkan bantuan.</translation>
    </message>
    <message>
        <source>Failed to take a continuous screenshot.</source>
        <translation>Gagal mengambil screenshot berkelanjutan.</translation>
    </message>
    <message>
        <source>Reached the bottom of the scroll area</source>
        <translation>Telah mencapai bagian bawah area gulir</translation>
    </message>
    <message>
        <source>Reached the maximum length</source>
        <translation>Telah mencapai panjang maksimum</translation>
    </message>
    <message>
        <source>adjust the capture area</source>
        <translation>sesuaikan area tangkapan</translation>
    </message>
    <message>
        <source>Scroll your mouse wheel or click to take a scrolling screenshot</source>
        <translation>Gulir roda mouse atau klik untuk mengambil screenshot bergerak</translation>
    </message>
    <message>
        <source>Slow down the scrolling speed</source>
        <translation>Lambatkan kecepatan gulir</translation>
    </message>
    <message>
        <source>Invalid area, click to </source>
        <translation>&apos;Area tidak valid, klik untuk &apos;</translation>
    </message>
</context>
<context>
    <name>ShapesWidget</name>
    <message>
        <source>Input text here</source>
        <translation>Masukkan teks di sini</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Start/Screenshot</source>
        <translation>Mulai/Cuplik layar</translation>
    </message>
    <message>
        <source>Exit/Save</source>
        <translation>Keluar/Simpan</translation>
    </message>
    <message>
        <source>Size Adjustment</source>
        <translation>Penyesuaian Ukuran</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Pengaturan</translation>
    </message>
    <message>
        <source>Quick start</source>
        <translation>Mulai Cepat</translation>
    </message>
    <message>
        <source>Window screenshot</source>
        <translation>Jendela cuplikan layar</translation>
    </message>
    <message>
        <source>Delay screenshot</source>
        <translation>Jeda cuplikan layar</translation>
    </message>
    <message>
        <source>Full screenshot</source>
        <translation>Cuplikan layar penuh</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Keluar</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Simpan</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>Persegi Panjang</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>Elips</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Garis</translation>
    </message>
    <message>
        <source>Pencil</source>
        <translation>Pensil</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Teks</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Hapus</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>Batal</translation>
    </message>
    <message>
        <source>Increase height up</source>
        <translation>Tinggi Naik</translation>
    </message>
    <message>
        <source>Increase height down</source>
        <translation>Tinggi Turun</translation>
    </message>
    <message>
        <source>Increase width left</source>
        <translation>Lebar Kiri</translation>
    </message>
    <message>
        <source>Increase width right</source>
        <translation>Lebar Kanan</translation>
    </message>
    <message>
        <source>Decrease height up</source>
        <translation>Tinggi Turun</translation>
    </message>
    <message>
        <source>Decrease height down</source>
        <translation>Tinggi Naik</translation>
    </message>
    <message>
        <source>Decrease width left</source>
        <translation>Lebar Kanan</translation>
    </message>
    <message>
        <source>Decrease width right</source>
        <translation>Lebar Kiri</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Bantuan</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Tampilkan Pintasan</translation>
    </message>
    <message>
        <source>Sound</source>
        <translation>Suara</translation>
    </message>
    <message>
        <source>Keystroke</source>
        <translation>Pintasan Tombol</translation>
    </message>
    <message>
        <source>Webcam</source>
        <translation>Webcam</translation>
    </message>
    <message>
        <source>Start recording</source>
        <translation>Mulai merekam</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Opsi</translation>
    </message>
    <message>
        <source>Start/Recording</source>
        <translation>Mulai/Merekam</translation>
    </message>
    <message>
        <source>Mouse</source>
        <translation>Mouse</translation>
    </message>
    <message>
        <source>Tools</source>
        <translation>Alat</translation>
    </message>
    <message>
        <source>Extract text</source>
        <translation>Ekstrak Teks</translation>
    </message>
    <message>
        <source>Scrollshot</source>
        <translation>Scrollshot</translation>
    </message>
    <message>
        <source>Pin screenshots</source>
        <translation>Pin Tampilan Layar</translation>
    </message>
    <message>
        <source>Start OCR</source>
        <translation>Mulai OCR</translation>
    </message>
    <message>
        <source>Start scrollshot</source>
        <translation>Mulai Scrollshot</translation>
    </message>
    <message>
        <source>Arrow</source>
        <translation>Panah</translation>
    </message>
</context>
<context>
    <name>ShotStartPlugin</name>
    <message>
        <source>Screenshot</source>
        <translation>Cuplikan layar</translation>
    </message>
</context>
<context>
    <name>ShotStartRecordPlugin</name>
    <message>
        <source>Record</source>
        <translation>Rekam</translation>
    </message>
</context>
<context>
    <name>ShotToolWidget</name>
    <message>
        <source>Rectangle
Press and hold Shift to draw a square</source>
        <translation>Persegi
Tekan dan tahan Shift untuk menggambar persegi panjang</translation>
    </message>
    <message>
        <source>Ellipse
Press and hold Shift to draw a circle</source>
        <translation>Elips
Tekan dan tahan Shift untuk menggambar lingkaran</translation>
    </message>
    <message>
        <source>Brush
Press and hold Shift to draw a straight line</source>
        <translation>Kuas
Tekan dan tahan Shift untuk menggambar garis lurus</translation>
    </message>
    <message>
        <source>Adjust blur strength (Scroll to adjust it)</source>
        <translation>Atur kekuatan blur (Geser untuk menyesuaikan)</translation>
    </message>
    <message>
        <source>Adjust brush size (Scroll to adjust it)</source>
        <translation>Atur ukuran kuas (Geser untuk menyesuaikan)</translation>
    </message>
    <message>
        <source>Adjust text size (Scroll to adjust it)</source>
        <translation>Atur ukuran teks (Geser untuk menyesuaikan)</translation>
    </message>
</context>
<context>
    <name>StartTooltip</name>
    <message>
        <source>Click or drag to
select the area to record</source>
        <translation>Klik atau seret ke
pilih area untuk rekam</translation>
    </message>
</context>
<context>
    <name>SubToolWidget</name>
    <message>
        <source>Show keystroke (K)</source>
        <translation>Tampilkan tombol pintasan (K)</translation>
    </message>
    <message>
        <source>Hide Keystroke (K)</source>
        <translation>Sembunyikan tombol pintasan (K)</translation>
    </message>
    <message>
        <source>Show Keystroke (K)</source>
        <translation>Tampilkan tombol pintasan (K)</translation>
    </message>
    <message>
        <source>Turn on camera (C)</source>
        <translation>Nyalakan kamera (C)</translation>
    </message>
    <message>
        <source>Turn off camera (C)</source>
        <translation>Matikan kamera (C)</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>Cuplikan layar</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Pengaturan</translation>
    </message>
    <message>
        <source>Settings (F3)</source>
        <translation>Pengaturan (F3)</translation>
    </message>
    <message>
        <source>Format:</source>
        <translation>Format:</translation>
    </message>
    <message>
        <source>GIF</source>
        <translation>GIF</translation>
    </message>
    <message>
        <source>MP4</source>
        <translation>MP4</translation>
    </message>
    <message>
        <source>MKV</source>
        <translation>MKV</translation>
    </message>
    <message>
        <source>webm</source>
        <translation>webm</translation>
    </message>
    <message>
        <source>FPS:</source>
        <translation>FPS:</translation>
    </message>
    <message>
        <source>5 fps</source>
        <translation>5 fps</translation>
    </message>
    <message>
        <source>10 fps</source>
        <translation>10 fps</translation>
    </message>
    <message>
        <source>20 fps</source>
        <translation>20 fps</translation>
    </message>
    <message>
        <source>24 fps</source>
        <translation>24 fps</translation>
    </message>
    <message>
        <source>30 fps</source>
        <translation>30 fps</translation>
    </message>
    <message>
        <source>Sound</source>
        <translation>Suara</translation>
    </message>
    <message>
        <source>Microphone</source>
        <translation>Mic</translation>
    </message>
    <message>
        <source>System audio</source>
        <translation>Audio sistem</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Opsi</translation>
    </message>
    <message>
        <source>Show pointer</source>
        <translation>Tampilkan penunjuk</translation>
    </message>
    <message>
        <source>Show click</source>
        <translation>Tunjukkan klik</translation>
    </message>
    <message>
        <source>Save to</source>
        <translation>Simpan ke</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation>Meja</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Video</translation>
    </message>
    <message>
        <source>Rectangle (R)
Press and hold Shift to draw a square</source>
        <translation>Persegi (R)
Tekan dan tahan Shift untuk menggambar persegi panjang</translation>
    </message>
    <message>
        <source>Ellipse (O)
Press and hold Shift to draw a circle</source>
        <translation>Elips (O)
Tekan dan tahan Shift untuk menggambar lingkaran</translation>
    </message>
    <message>
        <source>Line (L)
Press and hold Shift to draw a vertical or horizontal line</source>
        <translation>Garis (L)
Tekan dan tahan Shift untuk menggambar garis vertikal atau horizontal</translation>
    </message>
    <message>
        <source>Arrow (X)
Press and hold Shift to draw a vertical or horizontal arrow</source>
        <translation>Panah (X)
Tekan dan tahan Shift untuk menggambar panah vertikal atau horizontal</translation>
    </message>
    <message>
        <source>Pencil (P)</source>
        <translation>Pensil (P)</translation>
    </message>
    <message>
        <source>Blur (B)</source>
        <translation>Kabur (B)</translation>
    </message>
    <message>
        <source>Text (T)</source>
        <translation>Teks (T)</translation>
    </message>
    <message>
        <source>Scrollshot (Alt+I）</source>
        <translation>Scrollshot (Alt+I)</translation>
    </message>
    <message>
        <source>Extract text (Alt+O）</source>
        <translation>Ekstrak teks (Alt+O)</translation>
    </message>
    <message>
        <source>Pin screenshots (Alt+P）</source>
        <translation>Pin screenshot (Alt+P)</translation>
    </message>
    <message>
        <source>Undo (Ctrl+Z)</source>
        <translation>Batal (Ctrl+Z)</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>Rekam</translation>
    </message>
    <message>
        <source>Clipboard</source>
        <translation>Papan Klip</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Gambar</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation>Folder</translation>
    </message>
    <message>
        <source>Set a path on save</source>
        <translation>Tetapkan jalur saat menyimpan</translation>
    </message>
    <message>
        <source>Change the path on save</source>
        <translation>Ubah jalur saat menyimpan</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Format</translation>
    </message>
    <message>
        <source>PNG</source>
        <translation>PNG</translation>
    </message>
    <message>
        <source>JPG</source>
        <translation>JPG</translation>
    </message>
    <message>
        <source>BMP</source>
        <translation>BMP</translation>
    </message>
    <message>
        <source>Border Effects</source>
        <translation>Efek Border</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Tidak Ada</translation>
    </message>
    <message>
        <source>Shadow</source>
        <translation>Bayangan</translation>
    </message>
    <message>
        <source>Border</source>
        <translation>Border</translation>
    </message>
    <message>
        <source>Device</source>
        <translation>Perangkat</translation>
    </message>
    <message>
        <source>Extract Text</source>
        <translation>Ekstrak Teks</translation>
    </message>
</context>
<context>
    <name>ToolBarWidget</name>
    <message>
        <source>Close (Esc)</source>
        <translation>Tutup (Esc)</translation>
    </message>
    <message>
        <source>OK (Enter)</source>
        <translation>OK (Enter)</translation>
    </message>
</context>
<context>
    <name>TopTips</name>
    <message>
        <source> Adjust the recording area within %1*%2 to get better video effect</source>
        <translation>Sesuaikan area perekaman dalam %1*%2 untuk mendapatkan efek video yang lebih baik</translation>
    </message>
</context>
<context>
    <name>Utils</name>
    <message>
        <source>Screen recording is not supported at present</source>
        <translation>Perekaman layar tidak didukung saat ini</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Keluar</translation>
    </message>
</context>
<context>
    <name>VoiceRecordProcess</name>
    <message>
        <source>New recording</source>
        <translation>Perekaman baru</translation>
    </message>
</context>
</TS>
